@@ -35,11 +35,12 @@ class Anilist:
     def getAnimeID(self, anime_name):
         data = self.extractID.anime(anime_name)
         max_result = 0
-        counter = 0
+        counter = 1
         for i in range(len(data['data']['Page']['media'])):
             curr_anime = data['data']['Page']['media'][i]['title']['romaji']
             print(f"{counter}. {curr_anime}")
             max_result = i + 1
+            counter += 1
         
         try:
             user_input = int(input("Please select the anime that you are searching for in number: "))
@@ -126,6 +127,7 @@ class Anilist:
     # CHARACTER =================================================================================================
     def getCharacterID(self, character_name):
         max_result = 0
+        counter = 1
         data = self.extractID.character(character_name)
         for i in range(len(data['data']['Page']['characters'])):
             first_name = data['data']['Page']['characters'][i]['name']['first']
@@ -133,11 +135,12 @@ class Anilist:
             max_result = i + 1
 
             if last_name == None:
-                print(first_name)
+                print(f"{counter}. {first_name}")
             elif first_name == None:
-                print(last_name)
+                print(f"{counter}. {last_name}")
             else:
-                print(f'{last_name}, {first_name}')
+                print(f'{counter}. {last_name}, {first_name}')
+            counter += 1
 
         try:
             user_input = int(input("Please select the character that you are searching for in number: "))
